@@ -351,6 +351,41 @@ fn benchmark_many_tuple_assignments(criterion: &mut Criterion) {
     });
 }
 
+fn benchmark_tuple_implicit_instance_attributes(criterion: &mut Criterion) {
+    setup_rayon();
+
+    criterion.bench_function("ty_micro[many_tuple_assignments]", |b| {
+        b.iter_batched_ref(
+            || {
+                // This is a regression benchmark for a case that used to hang:
+                // https://github.com/astral-sh/ty/issues/765
+                setup_micro_case(
+                    r#"
+                    from typing import Any
+
+                    class A:
+                        foo: tuple[Any, ...]
+
+                    class B(A):
+                        def __init__(self, parent: "C", x: tuple[Any]):
+                            self.foo = parent.foo + x
+
+                    class C(A):
+                        def __init__(self, parent: B, x: tuple[Any]):
+                            self.foo = parent.foo + x
+                    "#,
+                )
+            },
+            |case| {
+                let Case { db, .. } = case;
+                let result = db.check();
+                assert_eq!(result.len(), 0);
+            },
+            BatchSize::SmallInput,
+        );
+    });
+}
+
 fn benchmark_complex_constrained_attributes_1(criterion: &mut Criterion) {
     setup_rayon();
 
@@ -409,15 +444,12 @@ fn benchmark_complex_constrained_attributes_2(criterion: &mut Criterion) {
     criterion.bench_function("ty_micro[complex_constrained_attributes_2]", |b| {
         b.iter_batched_ref(
             || {
-                // This is is similar to the case above, but now the attributes are actually defined.
+                // This is similar to the case above, but now the attributes are actually defined.
                 // https://github.com/astral-sh/ty/issues/711
                 setup_micro_case(
                     r#"
                     class C:
                         def f(self: "C"):
-                            self.a = ""
-                            self.b = ""
-
                             if isinstance(self.a, str):
                                 return
 
@@ -431,6 +463,56 @@ fn benchmark_complex_constrained_attributes_2(criterion: &mut Criterion) {
                                 return
                             if isinstance(self.b, str):
                                 return
+                            if isinstance(self.b, str):
+                                return
+                            if isinstance(self.b, str):
+                                return
+
+                            self.a = ""
+                            self.b = ""
+                    "#,
+                )
+            },
+            |case| {
+                let Case { db, .. } = case;
+                let result = db.check();
+                assert_eq!(result.len(), 0);
+            },
+            BatchSize::SmallInput,
+        );
+    });
+}
+
+fn benchmark_complex_constrained_attributes_3(criterion: &mut Criterion) {
+    setup_rayon();
+
+    criterion.bench_function("ty_micro[complex_constrained_attributes_3]", |b| {
+        b.iter_batched_ref(
+            || {
+                // This is a regression test for https://github.com/astral-sh/ty/issues/758
+                setup_micro_case(
+                    r#"
+                    class GridOut:
+                        def __init__(self: "GridOut") -> None:
+                            self._buffer = b""
+
+                        def _read_size_or_line(self: "GridOut", size: int = -1):
+                            if size > self._position:
+                                size = self._position
+                                pass
+                            if size == 0:
+                                return bytes()
+
+                            while size > 0:
+                                if self._buffer:
+                                    buf = self._buffer
+                                    self._buffer = b""
+                                else:
+                                    buf = b""
+
+                                if len(buf) > size:
+                                    self._buffer = buf
+                                    self._position -= len(self._buffer)
                     "#,
                 )
             },
@@ -630,8 +712,10 @@ criterion_group!(
     micro,
     benchmark_many_string_assignments,
     benchmark_many_tuple_assignments,
+    benchmark_tuple_implicit_instance_attributes,
     benchmark_complex_constrained_attributes_1,
     benchmark_complex_constrained_attributes_2,
+    benchmark_complex_constrained_attributes_3,
     benchmark_many_enum_members,
 );
 criterion_group!(project, anyio, attrs, hydra, datetype);
